@@ -2,6 +2,7 @@
 Threshold Graphs - Creation, manipulation and identification.
 """
 from math import sqrt
+
 import networkx as nx
 from networkx.utils import py_random_state
 
@@ -41,13 +42,13 @@ def is_threshold_graph(G):
 
 def is_threshold_sequence(degree_sequence):
     """
-    Returns True if the sequence is a threshold degree seqeunce.
+    Returns True if the sequence is a threshold degree sequence.
 
     Uses the property that a threshold graph must be constructed by
     adding either dominating or isolated nodes. Thus, it can be
     deconstructed iteratively by removing a node of degree zero or a
     node that connects to the remaining nodes.  If this deconstruction
-    failes then the sequence is not a threshold sequence.
+    fails then the sequence is not a threshold sequence.
     """
     ds = degree_sequence[:]  # get a copy so we don't destroy original
     ds.sort()
@@ -94,7 +95,7 @@ def creation_sequence(degree_sequence, with_labels=False, compact=False):
         raise ValueError("compact sequences cannot be labeled")
 
     # make an indexed copy
-    if isinstance(degree_sequence, dict):  # labeled degree seqeunce
+    if isinstance(degree_sequence, dict):  # labeled degree sequence
         ds = [[degree, label] for (label, degree) in degree_sequence.items()]
     else:
         ds = [[d, i] for i, d in enumerate(degree_sequence)]
@@ -231,7 +232,7 @@ def creation_sequence_to_weights(creation_sequence):
     # Now scale weights
     if prev == "d":
         w += 1
-    wscale = 1.0 / float(w)
+    wscale = 1 / w
     return [ww * wscale for ww in wseq]
     # return wseq
 
@@ -492,7 +493,7 @@ def cluster_sequence(creation_sequence):
             cseq.append(0)
             continue
         max_size = (deg * (deg - 1)) // 2
-        cseq.append(float(tri) / float(max_size))
+        cseq.append(tri / max_size)
     return cseq
 
 
@@ -521,7 +522,7 @@ def density(creation_sequence):
     N = len(creation_sequence)
     two_size = sum(degree_sequence(creation_sequence))
     two_possible = N * (N - 1)
-    den = two_size / float(two_possible)
+    den = two_size / two_possible
     return den
 
 
@@ -556,7 +557,7 @@ def degree_correlation(creation_sequence):
         if numer == 0:
             return 1
         raise ValueError(f"Zero Denominator but Numerator is {numer}")
-    return numer / float(denom)
+    return numer / denom
 
 
 def shortest_path(creation_sequence, u, v):
@@ -667,7 +668,7 @@ def betweenness_sequence(creation_sequence, normalized=True):
     cs = creation_sequence
     seq = []  # betweenness
     lastchar = "d"  # first node is always a 'd'
-    dr = float(cs.count("d"))  # number of d's to the right of curren pos
+    dr = float(cs.count("d"))  # number of d's to the right of current pos
     irun = 0  # number of i's in the last run
     drun = 0  # number of d's in the last run
     dlast = 0.0  # betweenness of last d
