@@ -1,29 +1,19 @@
-# breadth_first_search.py - breadth-first traversal of a graph
-#
-# Copyright (C) 2004-2019 NetworkX Developers
-#   Aric Hagberg <hagberg@lanl.gov>
-#   Dan Schult <dschult@colgate.edu>
-#   Pieter Swart <swart@lanl.gov>
-#
-# This file is part of NetworkX.
-#
-# NetworkX is distributed under a BSD license; see LICENSE.txt for more
-# information.
-#
-# Authors:
-#     Aric Hagberg <aric.hagberg@gmail.com>
-#
 """Basic algorithms for breadth-first searching the nodes of a graph."""
-import networkx as nx
 from collections import deque
 
+import networkx as nx
+
 __all__ = [
-    'bfs_edges', 'bfs_tree', 'bfs_predecessors', 'bfs_successors',
-    'descendants_at_distance'
+    "bfs_edges",
+    "bfs_tree",
+    "bfs_predecessors",
+    "bfs_successors",
+    "descendants_at_distance",
+    "bfs_layers",
 ]
 
 
-def generic_bfs_edges(G, source, neighbors=None, depth_limit=None):
+def generic_bfs_edges(G, source, neighbors=None, depth_limit=None, sort_neighbors=None):
     """Iterate over edges in a breadth-first search.
 
     The breadth-first search begins at `source` and enqueues the
@@ -50,6 +40,10 @@ def generic_bfs_edges(G, source, neighbors=None, depth_limit=None):
     depth_limit : int, optional(default=len(G))
         Specify the maximum search depth
 
+    sort_neighbors : function
+        A function that takes the list of neighbors of given node as input, and
+        returns an *iterator* over these neighbors but with custom ordering.
+
     Yields
     ------
     edge
@@ -58,7 +52,7 @@ def generic_bfs_edges(G, source, neighbors=None, depth_limit=None):
     Examples
     --------
     >>> G = nx.path_graph(3)
-    >>> print(list(nx.bfs_edges(G,0)))
+    >>> print(list(nx.bfs_edges(G, 0)))
     [(0, 1), (1, 2)]
     >>> print(list(nx.bfs_edges(G, source=0, depth_limit=1)))
     [(0, 1)]
@@ -73,6 +67,10 @@ def generic_bfs_edges(G, source, neighbors=None, depth_limit=None):
     .. _PADS: http://www.ics.uci.edu/~eppstein/PADS/BFS.py
     .. _Depth-limited-search: https://en.wikipedia.org/wiki/Depth-limited_search
     """
+    if callable(sort_neighbors):
+        _neighbors = neighbors
+        neighbors = lambda node: iter(sort_neighbors(_neighbors(node)))
+
     visited = {source}
     if depth_limit is None:
         depth_limit = len(G)
@@ -90,7 +88,8 @@ def generic_bfs_edges(G, source, neighbors=None, depth_limit=None):
             queue.popleft()
 
 
-def bfs_edges(G, source, reverse=False, depth_limit=None):
+@nx._dispatch
+def bfs_edges(G, source, reverse=False, depth_limit=None, sort_neighbors=None):
     """Iterate over edges in a breadth-first-search starting at source.
 
     Parameters
@@ -108,10 +107,14 @@ def bfs_edges(G, source, reverse=False, depth_limit=None):
     depth_limit : int, optional(default=len(G))
         Specify the maximum search depth
 
-    Returns
-    -------
-    edges: generator
-       A generator of edges in the breadth-first-search.
+    sort_neighbors : function
+        A function that takes the list of neighbors of given node as input, and
+        returns an *iterator* over these neighbors but with custom ordering.
+
+    Yields
+    ------
+    edge: 2-tuple of nodes
+       Yields edges resulting from the breadth-first search.
 
     Examples
     --------
@@ -134,39 +137,40 @@ def bfs_edges(G, source, reverse=False, depth_limit=None):
 
     Notes
     -----
-    The naming of this function is very similar to bfs_edges. The difference
-    is that 'edge_bfs' yields edges even if they extend back to an already
-    explored node while 'bfs_edges' yields the edges of the tree that results
+    The naming of this function is very similar to
+    :func:`~networkx.algorithms.traversal.edgebfs.edge_bfs`. The difference
+    is that ``edge_bfs`` yields edges even if they extend back to an already
+    explored node while this generator yields the edges of the tree that results
     from a breadth-first-search (BFS) so no edges are reported if they extend
-    to already explored nodes. That means 'edge_bfs' reports all edges while
-    'bfs_edges' only report those traversed by a node-based BFS. Yet another
-    description is that 'bfs_edges' reports the edges traversed during BFS
-    while 'edge_bfs' reports all edges in the order they are explored.
+    to already explored nodes. That means ``edge_bfs`` reports all edges while
+    ``bfs_edges`` only reports those traversed by a node-based BFS. Yet another
+    description is that ``bfs_edges`` reports the edges traversed during BFS
+    while ``edge_bfs`` reports all edges in the order they are explored.
 
-    Based on http://www.ics.uci.edu/~eppstein/PADS/BFS.py.
-    by D. Eppstein, July 2004. The modifications
-    to allow depth limits based on the Wikipedia article
-    "`Depth-limited-search`_".
+    Based on the breadth-first search implementation in PADS [1]_
+    by D. Eppstein, July 2004; with modifications to allow depth limits
+    as described in [2]_.
 
-    .. _Depth-limited-search: https://en.wikipedia.org/wiki/Depth-limited_search
+    References
+    ----------
+    .. [1] http://www.ics.uci.edu/~eppstein/PADS/BFS.py.
+    .. [2] https://en.wikipedia.org/wiki/Depth-limited_search
 
     See Also
     --------
     bfs_tree
-    dfs_edges
-    edge_bfs
+    :func:`~networkx.algorithms.traversal.depth_first_search.dfs_edges`
+    :func:`~networkx.algorithms.traversal.edgebfs.edge_bfs`
 
     """
     if reverse and G.is_directed():
         successors = G.predecessors
     else:
         successors = G.neighbors
-    # TODO In Python 3.3+, this should be `yield from ...`
-    for e in generic_bfs_edges(G, source, successors, depth_limit):
-        yield e
+    yield from generic_bfs_edges(G, source, successors, depth_limit, sort_neighbors)
 
 
-def bfs_tree(G, source, reverse=False, depth_limit=None):
+def bfs_tree(G, source, reverse=False, depth_limit=None, sort_neighbors=None):
     """Returns an oriented tree constructed from of a breadth-first-search
     starting at source.
 
@@ -183,6 +187,10 @@ def bfs_tree(G, source, reverse=False, depth_limit=None):
     depth_limit : int, optional(default=len(G))
         Specify the maximum search depth
 
+    sort_neighbors : function
+        A function that takes the list of neighbors of given node as input, and
+        returns an *iterator* over these neighbors but with custom ordering.
+
     Returns
     -------
     T: NetworkX DiGraph
@@ -191,7 +199,7 @@ def bfs_tree(G, source, reverse=False, depth_limit=None):
     Examples
     --------
     >>> G = nx.path_graph(3)
-    >>> print(list(nx.bfs_tree(G,1).edges()))
+    >>> print(list(nx.bfs_tree(G, 1).edges()))
     [(1, 0), (1, 2)]
     >>> H = nx.Graph()
     >>> nx.add_path(H, [0, 1, 2, 3, 4, 5, 6])
@@ -217,12 +225,18 @@ def bfs_tree(G, source, reverse=False, depth_limit=None):
     """
     T = nx.DiGraph()
     T.add_node(source)
-    edges_gen = bfs_edges(G, source, reverse=reverse, depth_limit=depth_limit)
+    edges_gen = bfs_edges(
+        G,
+        source,
+        reverse=reverse,
+        depth_limit=depth_limit,
+        sort_neighbors=sort_neighbors,
+    )
     T.add_edges_from(edges_gen)
     return T
 
 
-def bfs_predecessors(G, source, depth_limit=None):
+def bfs_predecessors(G, source, depth_limit=None, sort_neighbors=None):
     """Returns an iterator of predecessors in breadth-first-search from source.
 
     Parameters
@@ -235,11 +249,15 @@ def bfs_predecessors(G, source, depth_limit=None):
     depth_limit : int, optional(default=len(G))
         Specify the maximum search depth
 
+    sort_neighbors : function
+        A function that takes the list of neighbors of given node as input, and
+        returns an *iterator* over these neighbors but with custom ordering.
+
     Returns
     -------
     pred: iterator
-        (node, predecessors) iterator where predecessors is the list of
-        predecessors of the node.
+        (node, predecessor) iterator where `predecessor` is the predecessor of
+        `node` in a breadth first search starting from `source`.
 
     Examples
     --------
@@ -255,7 +273,11 @@ def bfs_predecessors(G, source, depth_limit=None):
     >>> nx.add_path(M, [2, 7, 8, 9, 10])
     >>> print(sorted(nx.bfs_predecessors(M, source=1, depth_limit=3)))
     [(0, 1), (2, 1), (3, 2), (4, 3), (7, 2), (8, 7)]
-
+    >>> N = nx.DiGraph()
+    >>> nx.add_path(N, [0, 1, 2, 3, 4, 7])
+    >>> nx.add_path(N, [3, 5, 6, 7])
+    >>> print(sorted(nx.bfs_predecessors(N, source=2)))
+    [(3, 2), (4, 3), (5, 3), (6, 5), (7, 4)]
 
     Notes
     -----
@@ -272,11 +294,13 @@ def bfs_predecessors(G, source, depth_limit=None):
     bfs_edges
     edge_bfs
     """
-    for s, t in bfs_edges(G, source, depth_limit=depth_limit):
+    for s, t in bfs_edges(
+        G, source, depth_limit=depth_limit, sort_neighbors=sort_neighbors
+    ):
         yield (t, s)
 
 
-def bfs_successors(G, source, depth_limit=None):
+def bfs_successors(G, source, depth_limit=None, sort_neighbors=None):
     """Returns an iterator of successors in breadth-first-search from source.
 
     Parameters
@@ -289,16 +313,21 @@ def bfs_successors(G, source, depth_limit=None):
     depth_limit : int, optional(default=len(G))
         Specify the maximum search depth
 
+    sort_neighbors : function
+        A function that takes the list of neighbors of given node as input, and
+        returns an *iterator* over these neighbors but with custom ordering.
+
     Returns
     -------
     succ: iterator
-       (node, successors) iterator where successors is the list of
-       successors of the node.
+       (node, successors) iterator where `successors` is the non-empty list of
+       successors of `node` in a breadth first search from `source`.
+       To appear in the iterator, `node` must have successors.
 
     Examples
     --------
     >>> G = nx.path_graph(3)
-    >>> print(dict(nx.bfs_successors(G,0)))
+    >>> print(dict(nx.bfs_successors(G, 0)))
     {0: [1], 1: [2]}
     >>> H = nx.Graph()
     >>> H.add_edges_from([(0, 1), (0, 2), (1, 3), (1, 4), (2, 5), (2, 6)])
@@ -309,7 +338,10 @@ def bfs_successors(G, source, depth_limit=None):
     >>> nx.add_path(G, [2, 7, 8, 9, 10])
     >>> print(dict(nx.bfs_successors(G, source=1, depth_limit=3)))
     {1: [0, 2], 2: [3, 7], 3: [4], 7: [8]}
-
+    >>> G = nx.DiGraph()
+    >>> nx.add_path(G, [0, 1, 2, 3, 4, 5])
+    >>> print(dict(nx.bfs_successors(G, source=3)))
+    {3: [4], 4: [5]}
 
     Notes
     -----
@@ -328,7 +360,9 @@ def bfs_successors(G, source, depth_limit=None):
     """
     parent = source
     children = []
-    for p, c in bfs_edges(G, source, depth_limit=depth_limit):
+    for p, c in bfs_edges(
+        G, source, depth_limit=depth_limit, sort_neighbors=sort_neighbors
+    ):
         if p == parent:
             children.append(c)
             continue
@@ -338,13 +372,64 @@ def bfs_successors(G, source, depth_limit=None):
     yield (parent, children)
 
 
+def bfs_layers(G, sources):
+    """Returns an iterator of all the layers in breadth-first search traversal.
+
+    Parameters
+    ----------
+    G : NetworkX graph
+        A graph over which to find the layers using breadth-first search.
+
+    sources : node in `G` or list of nodes in `G`
+        Specify starting nodes for single source or multiple sources breadth-first search
+
+    Yields
+    ------
+    layer: list of nodes
+        Yields list of nodes at the same distance from sources
+
+    Examples
+    --------
+    >>> G = nx.path_graph(5)
+    >>> dict(enumerate(nx.bfs_layers(G, [0, 4])))
+    {0: [0, 4], 1: [1, 3], 2: [2]}
+    >>> H = nx.Graph()
+    >>> H.add_edges_from([(0, 1), (0, 2), (1, 3), (1, 4), (2, 5), (2, 6)])
+    >>> dict(enumerate(nx.bfs_layers(H, [1])))
+    {0: [1], 1: [0, 3, 4], 2: [2], 3: [5, 6]}
+    >>> dict(enumerate(nx.bfs_layers(H, [1, 6])))
+    {0: [1, 6], 1: [0, 3, 4, 2], 2: [5]}
+    """
+    if sources in G:
+        sources = [sources]
+
+    current_layer = list(sources)
+    visited = set(sources)
+
+    for source in current_layer:
+        if source not in G:
+            raise nx.NetworkXError(f"The node {source} is not in the graph.")
+
+    # this is basically BFS, except that the current layer only stores the nodes at
+    # same distance from sources at each iteration
+    while current_layer:
+        yield current_layer
+        next_layer = list()
+        for node in current_layer:
+            for child in G[node]:
+                if child not in visited:
+                    visited.add(child)
+                    next_layer.append(child)
+        current_layer = next_layer
+
+
 def descendants_at_distance(G, source, distance):
     """Returns all nodes at a fixed `distance` from `source` in `G`.
 
     Parameters
     ----------
-    G : NetworkX DiGraph
-        A directed graph
+    G : NetworkX graph
+        A graph
     source : node in `G`
     distance : the distance of the wanted nodes from `source`
 
@@ -352,28 +437,26 @@ def descendants_at_distance(G, source, distance):
     -------
     set()
         The descendants of `source` in `G` at the given `distance` from `source`
+
+    Examples
+    --------
+    >>> G = nx.path_graph(5)
+    >>> nx.descendants_at_distance(G, 2, 2)
+    {0, 4}
+    >>> H = nx.DiGraph()
+    >>> H.add_edges_from([(0, 1), (0, 2), (1, 3), (1, 4), (2, 5), (2, 6)])
+    >>> nx.descendants_at_distance(H, 0, 2)
+    {3, 4, 5, 6}
+    >>> nx.descendants_at_distance(H, 5, 0)
+    {5}
+    >>> nx.descendants_at_distance(H, 5, 1)
+    set()
     """
-    if not G.has_node(source):
-        raise nx.NetworkXError("The node %s is not in the graph." % source)
-    current_distance = 0
-    queue = {source}
-    visited = {source}
-
-    # this is basically BFS, except that the queue only stores the nodes at
-    # current_distance from source at each iteration
-    while queue:
-        if current_distance == distance:
-            return queue
-
-        current_distance += 1
-
-        next_vertices = set()
-        for vertex in queue:
-            for child in G[vertex]:
-                if child not in visited:
-                    visited.add(child)
-                    next_vertices.add(child)
-
-        queue = next_vertices
+    if source not in G:
+        raise nx.NetworkXError(f"The node {source} is not in the graph.")
 
+    bfs_generator = nx.bfs_layers(G, source)
+    for i, layer in enumerate(bfs_generator):
+        if i == distance:
+            return set(layer)
     return set()
