@@ -1,7 +1,7 @@
 """Functions for generating line graphs."""
-from itertools import combinations
 from collections import defaultdict
 from functools import partial
+from itertools import combinations
 
 import networkx as nx
 from networkx.utils import arbitrary_element
@@ -43,6 +43,18 @@ def line_graph(G, create_using=None):
     >>> print(sorted(map(sorted, L.edges())))  # makes a 3-clique, K3
     [[(0, 1), (0, 2)], [(0, 1), (0, 3)], [(0, 2), (0, 3)]]
 
+    Edge attributes from `G` are not copied over as node attributes in `L`, but
+    attributes can be copied manually:
+
+    >>> G = nx.path_graph(4)
+    >>> G.add_edges_from((u, v, {"tot": u+v}) for u, v in G.edges)
+    >>> G.edges(data=True)
+    EdgeDataView([(0, 1, {'tot': 1}), (1, 2, {'tot': 3}), (2, 3, {'tot': 5})])
+    >>> H = nx.line_graph(G)
+    >>> H.add_nodes_from((node, G.edges[node]) for node in H)
+    >>> H.nodes(data=True)
+    NodeDataView({(0, 1): {'tot': 1}, (2, 3): {'tot': 5}, (1, 2): {'tot': 3}})
+
     Notes
     -----
     Graph, node, and edge data are not propagated to the new graph. For
@@ -234,7 +246,7 @@ def inverse_line_graph(G):
     This is an implementation of the Roussopoulos algorithm.
 
     If G consists of multiple components, then the algorithm doesn't work.
-    You should invert every component seperately:
+    You should invert every component separately:
 
     >>> K5 = nx.complete_graph(5)
     >>> P4 = nx.Graph([("a", "b"), ("b", "c"), ("c", "d")])
@@ -262,7 +274,14 @@ def inverse_line_graph(G):
     elif G.number_of_nodes() > 1 and G.number_of_edges() == 0:
         msg = (
             "inverse_line_graph() doesn't work on an edgeless graph. "
-            "Please use this function on each component seperately."
+            "Please use this function on each component separately."
+        )
+        raise nx.NetworkXError(msg)
+
+    if nx.number_of_selfloops(G) != 0:
+        msg = (
+            "A line graph as generated by NetworkX has no selfloops, so G has no "
+            "inverse line graph. Please remove the selfloops from G and try again."
         )
         raise nx.NetworkXError(msg)
 
@@ -368,13 +387,9 @@ def _find_partition(G, starting_cell):
     partitioned_vertices = list(starting_cell)
     while G_partition.number_of_edges() > 0:
         # there are still edges left and so more cells to be made
-        u = partitioned_vertices[-1]
+        u = partitioned_vertices.pop()
         deg_u = len(G_partition[u])
-        if deg_u == 0:
-            # if u has no edges left in G_partition then we have found
-            # all of its cells so we do not need to keep looking
-            partitioned_vertices.pop()
-        else:
+        if deg_u != 0:
             # if u still has edges then we need to find its other cell
             # this other cell must be a complete subgraph or else G is
             # not a line graph
@@ -421,6 +436,8 @@ def _select_starting_cell(G, starting_edge=None):
         e = arbitrary_element(G.edges())
     else:
         e = starting_edge
+        if e[0] not in G.nodes():
+            raise nx.NetworkXError(f"Vertex {e[0]} not in graph")
         if e[1] not in G[e[0]]:
             msg = f"starting_edge ({e[0]}, {e[1]}) is not in the Graph"
             raise nx.NetworkXError(msg)
@@ -435,10 +452,10 @@ def _select_starting_cell(G, starting_edge=None):
         T = e_triangles[0]
         a, b, c = T
         # ab was original edge so check the other 2 edges
-        ac_edges = [x for x in _triangles(G, (a, c))]
-        bc_edges = [x for x in _triangles(G, (b, c))]
-        if len(ac_edges) == 1:
-            if len(bc_edges) == 1:
+        ac_edges = len(_triangles(G, (a, c)))
+        bc_edges = len(_triangles(G, (b, c)))
+        if ac_edges == 1:
+            if bc_edges == 1:
                 starting_cell = T
             else:
                 return _select_starting_cell(G, starting_edge=(b, c))
@@ -457,29 +474,22 @@ def _select_starting_cell(G, starting_edge=None):
             starting_cell = T
         elif r - 1 <= s <= r:
             # check if odd triangles containing e form complete subgraph
-            # there must be exactly s+2 of them
-            # and they must all be connected
             triangle_nodes = set()
             for T in odd_triangles:
                 for x in T:
                     triangle_nodes.add(x)
-            if len(triangle_nodes) == s + 2:
-                for u in triangle_nodes:
-                    for v in triangle_nodes:
-                        if u != v and (v not in G[u]):
-                            msg = (
-                                "G is not a line graph (odd triangles "
-                                "do not form complete subgraph)"
-                            )
-                            raise nx.NetworkXError(msg)
-                # otherwise then we can use this as the starting cell
-                starting_cell = tuple(triangle_nodes)
-            else:
-                msg = (
-                    "G is not a line graph (odd triangles "
-                    "do not form complete subgraph)"
-                )
-                raise nx.NetworkXError(msg)
+
+            for u in triangle_nodes:
+                for v in triangle_nodes:
+                    if u != v and (v not in G[u]):
+                        msg = (
+                            "G is not a line graph (odd triangles "
+                            "do not form complete subgraph)"
+                        )
+                        raise nx.NetworkXError(msg)
+            # otherwise then we can use this as the starting cell
+            starting_cell = tuple(triangle_nodes)
+
         else:
             msg = (
                 "G is not a line graph (incorrect number of "
